@@ -1,5 +1,5 @@
 /* This file is part of KCachegrind.
-   Copyright (C) 2003 Josef Weidendorfer <Josef.Weidendorfer@gmx.de>
+   Copyright (C) 2003-2009 Josef Weidendorfer <Josef.Weidendorfer@gmx.de>
 
    KCachegrind is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -23,32 +23,37 @@
 #ifndef CALLVIEW_H
 #define CALLVIEW_H
 
-#include <q3listview.h>
+#include <QTreeWidget>
 #include "tracedata.h"
 #include "traceitemview.h"
 
-class CallView: public Q3ListView, public TraceItemView
+class CallView: public QTreeWidget, public TraceItemView
 {
   Q_OBJECT
 
 public:
   CallView(bool showCallers, TraceItemView* parentView,
-	   QWidget* parent=0, const char* name=0);
+           QWidget* parent=0);
 
   virtual QWidget* widget() { return this; }
   QString whatsThis() const;
   bool showCallers() const { return _showCallers; }
 
-private slots:
-  void context(Q3ListViewItem*,const QPoint &, int);
-  void selectedSlot(Q3ListViewItem*);
-  void activatedSlot(Q3ListViewItem*);
+protected slots:
+  void context(const QPoint &);
+  void selectedSlot(QTreeWidgetItem*, QTreeWidgetItem*);
+  void activatedSlot(QTreeWidgetItem*, int);
+  void headerClicked(int);
+
+protected:
+  void keyPressEvent(QKeyEvent* event);
 
 private:
   CostItem* canShow(CostItem*);
-  void doUpdate(int);
+  void doUpdate(int, bool);
   void refresh();
 
+  QStringList _headerLabels;
   bool _showCallers;
 };
 
