@@ -27,10 +27,7 @@
 #include "dbfilesmodel.h"
 #include "tmscanapi.h"
 
-#include <klocale.h>
-#include <kstandarddirs.h>
-#include <kxmlguifactory.h>
-#include <threadweaver/ThreadWeaver.h>
+#include <iostream>
 
 #include <QApplication>
 #include <QDesktopWidget>
@@ -44,9 +41,19 @@
 #include <QShortcut>
 #include <QDragEnterEvent>
 #include <QSortFilterProxyModel>
+#include <QStyledItemDelegate>
+#include <QStringBuilder>
+#include <QPainter>
+#include <QTextDocument>
+#include <QDomDocument>
 
-#include <iostream>
-
+#include <KColorScheme>
+#include <kactioncategory.h>
+#include <kaction.h>
+#include <klocale.h>
+#include <kstandarddirs.h>
+#include <kxmlguifactory.h>
+#include <threadweaver/ThreadWeaver.h>
 
 
 using namespace TM;
@@ -54,22 +61,80 @@ using namespace TM;
 
 //TODO do things for case when user explicitly wants to find & accel mark
 
-
-class FastSizeHintItemDelegate: public QItemDelegate
+void FastSizeHintItemDelegate::reset()
 {
-  //Q_OBJECT
+    cache.clear();
+}
 
-public:
-    FastSizeHintItemDelegate(int columnCount, QObject *parent)
-        : QItemDelegate(parent)
-    {Q_UNUSED(columnCount);}
-    ~FastSizeHintItemDelegate(){}
-
-/*    QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const
+QSize FastSizeHintItemDelegate::sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const
+{
+    int lineCount=1;
+    int nPos=20;
+    if (index.column()!=TMDBModel::Filepath && index.column()!=TMDBModel::TransationStatus)
     {
-        return QSize(100,30);
-    }*/
-};
+        QString text=index.data().toString();
+        nPos=text.indexOf('\n');
+        if (nPos==-1)
+            nPos=text.size();
+        else
+            lineCount+=text.count('\n');
+    }
+    static QFontMetrics metrics(option.font);
+    return QSize(metrics.averageCharWidth()*nPos, metrics.height()*lineCount);
+}
+
+void FastSizeHintItemDelegate::paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const
+{
+    painter->save();
+
+    const KColorScheme& scheme=activeScheme;
+    //painter->save();
+    painter->setClipping(true);
+    painter->setClipRect(option.rect);
+    QBrush bgBrush;
+    if (option.state&QStyle::State_MouseOver)
+        bgBrush=scheme.background(KColorScheme::LinkBackground);
+    else if (index.row()%2)
+        bgBrush=scheme.background(KColorScheme::AlternateBackground);
+    else
+        bgBrush=scheme.background(KColorScheme::NormalBackground);
+    
+    painter->fillRect(option.rect, bgBrush);
+    //painter->setFont(option.font);
+
+    RowColumnUnion rc;
+    rc.index.row=index.row();
+    rc.index.column=index.column();
+    //TMDBModel* m=static_cast<const TMDBModel*>(index.model());
+    if (!cache.contains(rc.v))
+    {
+        QString text=index.data(TMDBModel::HtmlDisplayRole).toString();
+        cache.insert(rc.v, new QStaticText(text));
+        cache.object(rc.v)->setTextFormat(index.column()<TMDBModel::Context?Qt::RichText:Qt::PlainText);
+        //qDebug()<<"-------------------";
+        //qDebug()<<text;
+    }
+    QStaticText* staticText=cache.object(rc.v);
+    staticText->setTextWidth(option.rect.width());
+    painter->drawStaticText(option.rect.topLeft(), *staticText);
+
+
+    painter->setPen(bgBrush.color());
+    QPoint p1=option.rect.topRight();
+    QPoint p2=option.rect.bottomRight();
+    int limit=qMin(16, option.rect.width());
+    int i=limit;
+    while(--i>0)
+    {
+        painter->setOpacity(float(i)/limit);
+        painter->drawLine(p1, p2);
+        int newX=p1.x()-1;
+        p1.setX(newX);
+        p2.setX(newX);
+    }
+    painter->restore();
+}
+
 
 //BEGIN TMDBModel
 TMDBModel::TMDBModel(QObject* parent)
@@ -131,17 +196,17 @@ void TMDBModel::setFilter(const QString& source, const QString& target,
     else
     {
         if (!escapedSource.isEmpty())
-            sourceQuery="AND source_strings.source "+invertSourceStr+"GLOB '"+escapedSource+"' ";
+            sourceQuery="AND source_strings.source "%invertSourceStr%"GLOB '"%escapedSource%"' ";
         if (!escapedTarget.isEmpty())
-            targetQuery="AND target_strings.target "+invertTargetStr+"GLOB '"+escapedTarget+"' ";
+            targetQuery="AND target_strings.target "%invertTargetStr%"GLOB '"%escapedTarget%"' ";
 
     }
     if (!filemask.isEmpty())
-        fileQuery="AND files.path GLOB '"+escapedFilemask+"' ";
+        fileQuery="AND files.path GLOB '"%escapedFilemask%"' ";
 
-    QString fromPart="FROM main JOIN source_strings ON (source_strings.id==main.source) "
-                     "JOIN target_strings ON (target_strings.id==main.target), files "
-                     "WHERE files.id==main.file "
+    QString fromPart="FROM main JOIN source_strings ON (source_strings.id=main.source) "
+                     "JOIN target_strings ON (target_strings.id=main.target), files "
+                     "WHERE files.id=main.file "
                      +sourceQuery
                      +targetQuery
                      +fileQuery;
@@ -193,16 +258,18 @@ int TMDBModel::translationStatus(const QModelIndex& item) const
 #define TM_DELIMITER '\v'
 QVariant TMDBModel::data(const QModelIndex& item, int role) const
 {
-    //TODO Qt::ForegroundRole -- brush for orphaned entries
-    if (role==Qt::FontRole && item.column()==TMDBModel::Target)
+    bool doHtml=(role==HtmlDisplayRole);
+    if (doHtml)
+        role=Qt::DisplayRole;
+    else if (role==Qt::FontRole && item.column()==TMDBModel::Target) //TODO Qt::ForegroundRole -- brush for orphaned entries
     {
         QFont font=QApplication::font();
         font.setItalic(!rowIsApproved(item.row()));
         return font;
     }
-    else if (role==FullPath && item.column()==TMDBModel::Filepath)
+    else if (role==FullPathRole && item.column()==TMDBModel::Filepath)
         return QSqlQueryModel::data(item, Qt::DisplayRole);
-    else if (role==TransState)
+    else if (role==TransStateRole)
         return translationStatus(item);
 
     QVariant result=QSqlQueryModel::data(item, role);
@@ -218,15 +285,13 @@ QVariant TMDBModel::data(const QModelIndex& item, int role) const
         if (pos!=-1)
             result=r.remove(pos, r.size());
     }
-    else if (item.column()<TMDBModel::Context)//source, target
+    else if (item.column()<TMDBModel::Context && !record(item.row()).isNull(TMDBModel::_SourceAccel+item.column()) )//source, target
     {
         const QVariant& posVar=record(item.row()).value(TMDBModel::_SourceAccel+item.column());
         int pos=-1;
         bool ok;
         if (posVar.isValid())
             pos=posVar.toInt(&ok);
-        //std::cout<<"ok "<<ok<<"; pos "<<pos<<"; column "<<item.column()<<" "<<TMDBModel::ColumnCount+item.column()<<std::endl;
-        //kWarning()<<QSqlQueryModel::data(QSqlQueryModel::index(item.row(),TMDBModel::TMDBModelColumnCount+item.column()));
         if (ok && pos!=-1)
         {
             QString r=result.toString();
@@ -248,10 +313,37 @@ QVariant TMDBModel::data(const QModelIndex& item, int role) const
                                    i18nc("@info:status","Untranslated")};
         return statuses[translationStatus(item)];
     }
-    return result;
+    if (doHtml && item.column()<TMDBModel::Context)
+    {
+        QString r=result.toString();
+        if (r.isEmpty())
+            return r;
+        r=Qt::convertFromPlainText(r); //FIXME use another routine (this has bugs)
+        if (item.column()==TMDBModel::Target && !rowIsApproved(item.row()))
+            r="<p><i>" % r.mid(3, r.length()-3) % "</i></p>";
+        return r;
+    }
+    else
+        return result;
 }
+
 //END TMDBModel
 
+struct StringRule
+{
+    QVector<QString> sources;
+    QVector<QString> targets;
+    QVector<QString> falseFriends;
+};
+
+struct Rule
+{
+    QVector<QRegExp> sources;
+    QVector<QRegExp> targets;
+    QVector<QRegExp> falseFriends;
+};
+
+
 //BEGIN TMResultsSortFilterProxyModel
 class TMResultsSortFilterProxyModel: public QSortFilterProxyModel
 {
@@ -259,21 +351,106 @@ public:
     TMResultsSortFilterProxyModel(QObject *parent)
         : QSortFilterProxyModel(parent)
     {}
+    void setRules(const QVector<Rule>& rules);
+    void fetchMore(const QModelIndex& parent);
+    QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const;
+
 protected:
     bool lessThan(const QModelIndex& left, const QModelIndex& right) const;
+    bool filterAcceptsRow(int source_row, const QModelIndex& source_parent) const;
+
+private:
+    QVector<Rule> m_rules;
+    mutable QMap<int,int> m_matchingRulesForSourceRow;
 };
 
 bool TMResultsSortFilterProxyModel::lessThan(const QModelIndex& left, const QModelIndex& right) const
 {
     if (left.column()==TMDBModel::TransationStatus)
     {
-        int l=left.data(TMDBModel::TransState).toInt();
-        int r=right.data(TMDBModel::TransState).toInt();
-        if (l!=r)
-            return l<r;
+        int l=left.data(TMDBModel::TransStateRole).toInt();
+        int r=right.data(TMDBModel::TransStateRole).toInt();
+        return l<r;
     }
     return QSortFilterProxyModel::lessThan(left, right);
 }
+
+void TMResultsSortFilterProxyModel::fetchMore(const QModelIndex& parent)
+{
+    int oldSourceRowCount=sourceModel()->rowCount();
+    int oldRowCount=rowCount();
+    QSortFilterProxyModel::fetchMore(parent);
+    
+    
+    while (oldRowCount==rowCount())
+    {
+        QSortFilterProxyModel::fetchMore(parent);
+        if (sourceModel()->rowCount()==oldSourceRowCount)
+            break;
+        oldSourceRowCount=sourceModel()->rowCount();
+    }
+    qDebug()<<"row count"<<sourceModel()->rowCount();
+}
+
+void TMResultsSortFilterProxyModel::setRules(const QVector<Rule>& rules)
+{
+    m_rules=rules;
+    invalidateFilter();
+}
+
+QVariant TMResultsSortFilterProxyModel::data(const QModelIndex& index, int role) const
+{
+    QVariant result=QSortFilterProxyModel::data(index, role);
+
+    if (m_rules.isEmpty() || role!=TMDBModel::HtmlDisplayRole)
+        return result;
+
+    if (index.column()!=TMDBModel::Source && index.column()!=TMDBModel::Target)
+        return result;
+
+    int source_row=mapToSource(index).row();
+    QString string=result.toString();
+    QVector<QRegExp> regExps;
+    if (index.column()==TMDBModel::Source)
+        regExps=m_rules[m_matchingRulesForSourceRow[source_row]].sources;
+    else
+        regExps=m_rules[m_matchingRulesForSourceRow[source_row]].falseFriends;
+
+    foreach(const QRegExp& re, regExps)
+    {
+        int pos=re.indexIn(string);
+        if (pos!=-1)
+            return string.replace(pos, re.matchedLength(), "<b>" % re.cap(0) % "</b>");
+    }
+
+    return result;
+}
+    
+bool TMResultsSortFilterProxyModel::filterAcceptsRow(int source_row, const QModelIndex& source_parent) const
+{
+    if (m_rules.isEmpty())
+        return true;
+
+    QString source=sourceModel()->index(source_row, TMDBModel::Source, source_parent).data().toString();
+    QString target=sourceModel()->index(source_row, TMDBModel::Target, source_parent).data().toString();
+
+    bool accept=false;
+    int i=0;
+    foreach(const Rule& rule, m_rules)
+    {
+        if (rule.sources.first().indexIn(source)!=-1)
+        {
+            if (rule.falseFriends.first().indexIn(target)!=-1)
+            {
+                accept=true;
+                m_matchingRulesForSourceRow[source_row]=i;
+                break;
+            }
+        }
+        i++;
+    }
+    return accept;
+}
 //END TMResultsSortFilterProxyModel
 
 //BEGIN TMWindow
@@ -285,6 +462,7 @@ TMTab::TMTab(QWidget *parent)
 {
     //setCaption(i18nc("@title:window","Translation Memory"),false);
     setWindowTitle(i18nc("@title:window","Translation Memory"));
+    setAcceptDrops(true);
 
     ui_queryOptions=new Ui_QueryOptions;
     QWidget* w=new QWidget(this);
@@ -300,13 +478,9 @@ TMTab::TMTab(QWidget *parent)
 
     QShortcut* sh=new QShortcut(Qt::CTRL+Qt::Key_L, this);
     connect(sh,SIGNAL(activated()),ui_queryOptions->querySource,SLOT(setFocus()));
-
+    setFocusProxy(ui_queryOptions->querySource);
 
     QTreeView* view=ui_queryOptions->treeView;
-    //QueryResultDelegate* delegate=new QueryResultDelegate(this);
-    //view->setItemDelegate(delegate);
-    //view->setSelectionBehavior(QAbstractItemView::SelectItems);
-    //connect(delegate,SIGNAL(fileOpenRequested(KUrl)),this,SIGNAL(fileOpenRequested(KUrl)));
     view->setContextMenuPolicy(Qt::ActionsContextMenu);
 
     QAction* a=new QAction(i18n("Copy source to clipboard"),view);
@@ -341,10 +515,15 @@ TMTab::TMTab(QWidget *parent)
     view->setModel(m_proxyModel);
     view->sortByColumn(TMDBModel::Filepath,Qt::AscendingOrder);
     view->setSortingEnabled(true);
-    //view->setItemDelegate(new FastSizeHintItemDelegate(4,this));
     view->setColumnHidden(TMDBModel::_SourceAccel,true);
     view->setColumnHidden(TMDBModel::_TargetAccel,true);
     view->setColumnHidden(TMDBModel::_Bits,true);
+    view->setItemDelegate(new FastSizeHintItemDelegate(this));
+    connect(m_model,SIGNAL(resultsFetched()),view->itemDelegate(),SLOT(reset()));
+    connect(m_model,SIGNAL(modelReset()),view->itemDelegate(),SLOT(reset()));
+    connect(m_model,SIGNAL(layoutChanged()),view->itemDelegate(),SLOT(reset()));
+    connect(m_model,SIGNAL(rowsMoved(QModelIndex,int,int,QModelIndex,int)),view->itemDelegate(),SLOT(reset()));
+
 
     connect(m_model,SIGNAL(resultsFetched()),this,SLOT(handleResults()));
     connect(m_model,SIGNAL(finalResultCountFetched(int)),this,SLOT(setTotalResultCount(int)));
@@ -355,24 +534,35 @@ TMTab::TMTab(QWidget *parent)
     btnGrp->addButton(ui_queryOptions->glob,(int)TMDBModel::Glob);
     connect(btnGrp,SIGNAL(buttonClicked(int)),m_model,SLOT(setQueryType(int)));
 
-    setAcceptDrops(true);
-    /*
-    ui_queryOptions.db->setModel(DBFilesModel::instance());
-    ui_queryOptions.db->setCurrentIndex(ui_queryOptions.db->findText(Project::instance()->projectID()));
-    connect(ui_queryOptions.db,SIGNAL(currentIndexChanged(QString)),
-            m_model,SLOT(setDB(QString)));
-    */
+    ui_queryOptions->dbName->setModel(DBFilesModel::instance());
+    ui_queryOptions->dbName->setRootModelIndex(DBFilesModel::instance()->rootIndex());
+    QPersistentModelIndex* pi=DBFilesModel::instance()->projectDBIndex();
+    if (pi)
+    {
+        ui_queryOptions->dbName->setCurrentIndex(pi->row());
+        ui_queryOptions->dbName->view()->setCurrentIndex(*pi);
+    }
+    connect(ui_queryOptions->dbName, SIGNAL(activated(QString)), m_model, SLOT(setDB(QString)));
+    //connect(ui_queryOptions->dbName, SIGNAL(activated(QString)), this, SLOT(performQuery()));
 
-    //m_dbCombo->setCurrentIndex(m_dbCombo->findText(Project::instance()->projectID()));
+    
+    connect(ui_queryOptions->qa, SIGNAL(toggled(bool)), this, SLOT(setQAMode(bool)));
 
     int i=6;
     while (--i>ID_STATUS_PROGRESS)
-        statusBarItems.insert(i,"");
+        statusBarItems.insert(i,QString());
 
     setXMLFile("translationmemoryrui.rc",true);
     dbusObjectPath();
 
 
+    KAction *action;
+    KActionCollection* ac=actionCollection();
+    KActionCategory* tm=new KActionCategory(i18nc("@title actions category","Translation Memory"), ac);
+
+    action = tm->addAction("tools_tm_manage",Project::instance(),SLOT(showTMManager()));
+    action->setText(i18nc("@action:inmenu","Manage translation memories"));
+
 
     KConfig config;
     KConfigGroup cg(&config,"MainWindow");
@@ -389,12 +579,6 @@ TMTab::~TMTab()
     ids.removeAll(m_dbusId);
 }
 
-void TMTab::selectDB(int i)
-{
-    Q_UNUSED(i);
-    //m_dbCombo->setCurrentIndex(i);
-}
-
 void TMTab::updateTM()
 {
     QList<QUrl> urls;
@@ -454,7 +638,7 @@ void TMTab::handleResults()
 //BEGIN resizeColumnToContents
     QTreeView* view=ui_queryOptions->treeView;
     static const int maxInitialWidths[4]={QApplication::desktop()->availableGeometry().width()/3,QApplication::desktop()->availableGeometry().width()/3, 50, 200};
-    int column=4;//sizeof(maxInitialWidths);
+    int column=sizeof(maxInitialWidths)/sizeof(int);
     while (--column>=0)
     {
         //view->resizeColumnToContents(i);
@@ -509,11 +693,84 @@ void TMTab::openFile()
                            item.sibling(item.row(),TMDBModel::Context).data().toString());
 }
 
-/*
-void TMWindow::setOptions(int i)
-{
 
-}*/
+static QRegExp domNodeToRegExp(const QDomNode& node)
+{
+    QRegExp re(node.toElement().text());
+    re.setMinimal(true);
+    return re;
+}
+
+static QVector<QRegExp> domListToRegExpVector(const QDomNodeList& nodes)
+{
+    QVector<QRegExp> result;
+    result.reserve(nodes.size());
+    for (int i=0;i<nodes.size();i++)
+        result.append(domNodeToRegExp(nodes.at(i)));
+
+    return result;
+}
+
+
+void TMTab::setQAMode(bool enable)
+{
+    if (!enable)
+    {
+        m_proxyModel->setRules(QVector<Rule>());
+        return;
+    }
+
+    qDebug()<<Project::instance()->qaPath();
+    QDomDocument doc;
+    QFile file(Project::instance()->qaPath());
+    if (file.open(QIODevice::ReadOnly))
+    {
+        bool ok=doc.setContent(&file);
+        file.close();
+        if (!ok)
+            return;
+    }
+    else
+    {
+        /*
+        doc.setContent(
+"<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
+"<qa version=\"1.0\">\n"
+"    <category name=\"default\">\n"
+"    </category>\n"
+"</qa>\n");
+*/
+    }
+
+    QVector<Rule> rules;
+    QDomNodeList m_categories=doc.elementsByTagName("category");
+    for (int i=0;i<m_categories.size();i++)
+    {
+        QDomNodeList m_rules=m_categories.at(i).toElement().elementsByTagName("rule");
+        for (int j=0;j<m_rules.size();j++)
+        {
+            Rule rule;
+            rule.sources=domListToRegExpVector(m_rules.at(j).toElement().elementsByTagName("source"));
+            rule.falseFriends=domListToRegExpVector(m_rules.at(j).toElement().elementsByTagName("falseFriend"));
+            rule.targets=domListToRegExpVector(m_rules.at(j).toElement().elementsByTagName("target"));
+            rules.append(rule);
+        }
+    }
+    m_proxyModel->setRules(rules);
+    static_cast<FastSizeHintItemDelegate*>(ui_queryOptions->treeView->itemDelegate())->reset();
+
+    /*QDomElement docElem = m_categories.at(0).toElement();
+
+    QDomNode n = docElem.firstChildElement();
+    while(!n.isNull())
+    {
+        QDomElement e = n.toElement();
+        qDebug() << e.tagName();
+        n = n.nextSiblingElement();
+    }*/
+    
+    performQuery();
+}
 
 
 //END TMWindow
