@@ -34,6 +34,7 @@
 
 #include <kcompletionbox.h>
 
+#include <QStringBuilder>
 #include <QPixmap>
 #include <QPushButton>
 #include <QPainter>
@@ -142,6 +143,7 @@ void XliffTextEditSpellInterface::setSpellCheckingEnabled(bool enable)
 TranslationUnitTextEdit::TranslationUnitTextEdit(Catalog* catalog, DocPosition::Part part, QWidget* parent)
     : KTextEdit(parent)
     , m_currentUnicodeNumber(0)
+    , m_langUsesSpaces(true)
     , m_catalog(catalog)
     , m_part(part)
     , m_highlighter(new SyntaxHighlighter(this))
@@ -171,13 +173,23 @@ void TranslationUnitTextEdit::fileLoaded()
     //"i use an english locale while translating kde pot files from english to hebrew" Bug #181989
     QLocale langLocale(langCode);
     Qt::LayoutDirection targetLanguageDirection=Qt::LeftToRight;
-    QLocale::Language rtlLanguages[]={QLocale::Arabic, QLocale::Hebrew, QLocale::Urdu, QLocale::Persian, QLocale::Pashto};
-    int i=sizeof (rtlLanguages);
+    static QLocale::Language rtlLanguages[]={QLocale::Arabic, QLocale::Hebrew, QLocale::Urdu, QLocale::Persian, QLocale::Pashto};
+    int i=sizeof(rtlLanguages)/sizeof(QLocale::Arabic);
     while (--i>=0 && langLocale.language()!=rtlLanguages[i])
         ;
     if (i!=-1)
         targetLanguageDirection=Qt::RightToLeft;
     setLayoutDirection(targetLanguageDirection);
+
+    if (m_part==DocPosition::Source)
+        return;
+
+    //"Some language do not need space between words. For example Chinese."
+    static QLocale::Language noSpaceLanguages[]={QLocale::Chinese};
+    i=sizeof(noSpaceLanguages)/sizeof(QLocale::Chinese);
+    while (--i>=0 && langLocale.language()!=noSpaceLanguages[i])
+        ;
+    m_langUsesSpaces=(i==-1);
 }
 
 void TranslationUnitTextEdit::reflectApprovementState()
@@ -509,7 +521,7 @@ void TranslationUnitTextEdit::contentsChanged(int offset, int charsRemoved, int
 
     if (charsAdded==1)
     {
-        int sp=target.lastIndexOf(CompletionStorage::instance()->rxSplit,offset);
+        int sp=target.lastIndexOf(CompletionStorage::instance()->rxSplit,offset-1);
         int len=(offset-sp);
         int wordCompletionLength=Settings::self()->wordCompletionLength();
         if (wordCompletionLength>=3 && len>=wordCompletionLength)
@@ -800,7 +812,8 @@ void TranslationUnitTextEdit::keyPressEvent(QKeyEvent *keyEvent)
         }
         else if(!(keyEvent->modifiers()&Qt::ControlModifier))
         {
-            if(pos>0
+            if(m_langUsesSpaces
+               &&pos>0
                &&!str.isEmpty()
                &&!str.at(pos-1).isSpace())
             {
@@ -892,11 +905,7 @@ void TranslationUnitTextEdit::keyReleaseEvent(QKeyEvent* e)
 QString TranslationUnitTextEdit::toPlainText()
 {
     QTextCursor cursor = textCursor();
-    // HACK temporary fix for bug 249373
-    //cursor.select(QTextCursor::Document);
-    cursor.setPosition(0);
-    cursor.movePosition(QTextCursor::End, QTextCursor::KeepAnchor);
-
+    cursor.select(QTextCursor::Document);
     QString text=cursor.selectedText();
     text.replace(QChar(8233),'\n');
 /*
@@ -1110,6 +1119,10 @@ bool TranslationUnitTextEdit::event(QEvent *event)
             QToolTip::showText(helpEvent->globalPos(),tooltip);
             return true;
         }
+
+        QString langCode=m_highlighter->currentLanguage();
+        QToolTip::showText(helpEvent->globalPos(),
+                           KGlobal::locale()->languageCodeToName(langCode)%" ("%langCode%")");
     }
     return KTextEdit::event(event);
 }
