@@ -1,11 +1,10 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2006                                               *
+ *   copyright (C) 2002-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -23,35 +22,17 @@
  * @see UMLObject UMLClassifierListItem UMLEntityConstraint
  * Bugs and comments to uml-devel@lists.sf.net or http://bugs.kde.org
  */
-class UMLCheckConstraint : public UMLEntityConstraint {
+class UMLCheckConstraint : public UMLEntityConstraint
+{
      Q_OBJECT
 public:
 
-    /**
-     * Sets up a constraint.
-     *
-     * @param parent    The parent of this UMLCheckConstraint.
-     * @param name      The name of this UMLCheckConstraint.
-     * @param id        The unique id given to this UMLCheckConstraint.
-     */
     UMLCheckConstraint(UMLObject *parent, const QString& name,
                        Uml::IDType id = Uml::id_None );
-
-    /**
-     * Sets up a constraint.
-     *
-     * @param parent    The parent of this UMLCheckConstraint.
-     */
     UMLCheckConstraint(UMLObject *parent);
 
-    /**
-     * Overloaded '==' operator
-     */
-    bool operator==(const UMLCheckConstraint &rhs);
+    bool operator==(const UMLCheckConstraint &rhs) const;
 
-    /**
-     * destructor.
-     */
     virtual ~UMLCheckConstraint();
 
     virtual void copyInto(UMLObject *lhs) const;
@@ -63,7 +44,7 @@ public:
     QString getFullyQualifiedName(const QString& separator = QString(),
                                   bool includeRoot = false) const;
 
-    void saveToXMI( QDomDocument & qDoc, QDomElement & qElement );
+    void saveToXMI(QDomDocument & qDoc, QDomElement & qElement);
 
     virtual bool showPropertiesDialog(QWidget* parent);
 
@@ -77,16 +58,13 @@ public:
 
 protected:
 
-    bool load( QDomElement & element );
+    bool load(QDomElement & element);
 
 private:
 
     void init();
 
-    /**
-     * The Check Condition
-     */
-    QString m_CheckCondition;
+    QString m_CheckCondition;   ///< the check condition
 
 };
 
