@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2009                                               *
+ *   copyright (C) 2002-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -23,7 +23,7 @@ namespace Uml
     CmdCreateWidget::CmdCreateWidget(UMLView* view, UMLWidget* w)
       : m_view(view), m_widget(w)
     {
-        setText(i18n("Create widget :") + w->name());
+        setText(i18n("Create widget : %1", w->name()));
     }
 
     CmdCreateWidget::~CmdCreateWidget()
