@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2010                                               *
+ *   copyright (C) 2004-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -13,6 +13,7 @@
 #include "codegenerator.h"
 
 // app includes
+#include "debug_utils.h"
 #include "overwritedialogue.h"
 #include "codeviewerdialog.h"
 #include "simplecodegenerator.h"
@@ -31,7 +32,6 @@
 #include "model_utils.h"
 
 // kde includes
-#include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kdialog.h>
@@ -372,6 +372,12 @@ void CodeGenerator::checkRemoveUMLObject(UMLObject * obj)
     }
 }
 
+/**
+ * Find a code document by the given classifier.
+ * NOTE: FIX, this should be 'protected' or we could have problems with CPP code generator
+ * @return      CodeDocument
+ * @param       classifier
+ */
 CodeDocument * CodeGenerator::findCodeDocumentByClassifier(UMLClassifier * classifier)
 {
     return findCodeDocumentByID(ID2STR(classifier->id()));
