@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2010                                               *
+ *   copyright (C) 2004-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -13,16 +13,14 @@
 #include "codegenobjectwithtextblocks.h"
 
 // local includes
-#include "umldoc.h"
 #include "codedocument.h"
 #include "codeoperation.h"
 #include "codegenerators/codegenfactory.h"
 #include "classifiercodedocument.h"
+#include "debug_utils.h"
 #include "hierarchicalcodeblock.h"
 #include "uml.h"
-
-// kde includes
-#include <kdebug.h>
+#include "umldoc.h"
 
 /**
  * Constructor
