@@ -4,22 +4,24 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2010                                               *
+ *   copyright (C) 2002-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
 #include "entityattribute.h"
-// qt/kde includes
-#include <kdebug.h>
-#include <QtCore/QRegExp>
+
 // app includes
+#include "debug_utils.h"
 #include "umlcanvasobject.h"
 #include "umldoc.h"
 #include "uml.h"
 #include "umlentityattributedialog.h"
 #include "object_factory.h"
 
+// qt includes
+#include <QtCore/QRegExp>
+
 /**
  * Sets up an entityattribute.
  * @param parent    The parent of this UMLEntityAttribute.
@@ -185,7 +187,7 @@ QString UMLEntityAttribute::toString(Uml::Signature_Type sig)
 /**
  * Overloaded '==' operator
  */
-bool UMLEntityAttribute::operator==(const UMLEntityAttribute &rhs)
+bool UMLEntityAttribute::operator==(const UMLEntityAttribute &rhs) const
 {
     if( this == &rhs )
         return true;
