@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2009                                               *
+ *   copyright (C) 2002-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -33,7 +33,7 @@ public:
 
     UMLEntityConstraint(UMLObject *parent);
 
-    bool operator==( const UMLEntityConstraint &rhs);
+    bool operator==( const UMLEntityConstraint &rhs) const;
 
     virtual ~UMLEntityConstraint();
 
