@@ -1,11 +1,10 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2004-2006                                               *
+ *   copyright (C) 2004-2009                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -36,20 +35,47 @@
 #include "objectwidget.h"
 #include "objectnodewidget.h"
 #include "pinwidget.h"
-
+#include "model_utils.h"  // for ENUM_NAMES only
 
 using namespace Uml;
 
-ToolBarStateOther::ToolBarStateOther(UMLView *umlView) : ToolBarStatePool(umlView) {
+/**
+ * Creates a new ToolBarStateOther.
+ * @param umlView The UMLView to use.
+ */
+ToolBarStateOther::ToolBarStateOther(UMLView *umlView)
+  : ToolBarStatePool(umlView)
+{
 }
 
-ToolBarStateOther::~ToolBarStateOther() {
+/**
+ * Destroys this ToolBarStateOther.
+ */
+ToolBarStateOther::~ToolBarStateOther()
+{
 }
 
-void ToolBarStateOther::setCurrentElement() {
+/**
+ * Overridden from base class to ignore associations and widgets and treat
+ * them as empty spaces to create widgets on it.
+ * Sets nothing.
+ */
+void ToolBarStateOther::setCurrentElement()
+{
 }
 
-void ToolBarStateOther::mouseReleaseEmpty() {
+/**
+ * Called when the release event happened on an empty space.
+ * Associations, widgets and actual empty spaces are all treated as empty
+ * spaces. It creates a new widget if the left button was released.
+ * The widget to create depends on the type of the toolbar button selected.
+ * If the widget is the visual representation of an UMLObject, the object
+ * factory handles its creation. Otherwise, the widget is created using
+ * newWidget().
+ * The UMLView is resized to fit on all the items.
+ */
+void ToolBarStateOther::mouseReleaseEmpty()
+{
     if (m_pMouseEvent->button() == Qt::LeftButton) {
         if (!newWidget()) {
             // Is UMLObject?
@@ -62,7 +88,12 @@ void ToolBarStateOther::mouseReleaseEmpty() {
     }
 }
 
-Uml::Object_Type ToolBarStateOther::getObjectType() {
+/**
+ * Returns the object type of this tool.
+ * @return The object type of this tool.
+ */
+Uml::Object_Type ToolBarStateOther::getObjectType()
+{
     Object_Type ot;
 
     switch(getButton()) {
@@ -86,9 +117,19 @@ Uml::Object_Type ToolBarStateOther::getObjectType() {
     return ot;
 }
 
-// TODO: The name is a bit confusing.
-bool ToolBarStateOther::newWidget() {
-    UMLWidget* umlWidget = NULL;
+/**
+ * Creates and adds a new widget to the UMLView (if widgets of that type
+ * don't have an associated UMLObject).
+ * If the type of the widget doesn't use an UMLObject (for example, a note
+ * or a box), it creates the widget, adds it to the view and returns true.
+ * Otherwise, it returns false.
+ *
+ * @return True if the widget was created, false otherwise.
+ * @todo Rename to something more clear. The name is a bit confusing.
+ */
+bool ToolBarStateOther::newWidget()
+{
+    UMLWidget* umlWidget = 0;
 
     switch (getButton()) {
         case WorkToolBar::tbb_Note:
@@ -174,44 +215,72 @@ bool ToolBarStateOther::newWidget() {
     }
 
     // Return false if we didn't find a suitable widget.
-    if (umlWidget == NULL) {
+    if (umlWidget == 0) {
         return false;
     }
 
     // Special treatment for some buttons
-    if (getButton() == WorkToolBar::tbb_Activity) {
-        Dialog_Utils::askNameForWidget(
-            umlWidget, i18n("Enter Activity Name"),
-            i18n("Enter the name of the new activity:"), i18n("new activity"));
-    } else if (getButton() == WorkToolBar::tbb_Accept_Signal
-            || getButton() == WorkToolBar::tbb_Send_Signal) {
-        Dialog_Utils::askNameForWidget(
-            umlWidget, i18n("Enter Signal Name"),
-            i18n("Enter Signal"), i18n("new Signal"));
-    } else if (getButton() == WorkToolBar::tbb_Accept_Time_Event) {
-        Dialog_Utils::askNameForWidget(
-            umlWidget, i18n("Enter Time Event Name"),
-            i18n("Enter Time Event"), i18n("new time event"));
-    } else if (getButton() == WorkToolBar::tbb_Seq_Combined_Fragment) {
-        dynamic_cast<CombinedFragmentWidget*>(umlWidget)->askNameForWidgetType(
-            umlWidget, i18n("Enter Combined Fragment Name"),
-            i18n("Enter the Combined Fragment"), i18n("new Combined Fragment"));
-    } else if (getButton() == WorkToolBar::tbb_State) {
-        Dialog_Utils::askNameForWidget(
-            umlWidget, i18n("Enter State Name"),
-            i18n("Enter the name of the new state:"), i18n("new state"));
-    } else if (getButton() == WorkToolBar::tbb_Text) {
-        // It is pretty invisible otherwise.
-        FloatingTextWidget* ft = (FloatingTextWidget*) umlWidget;
-        ft->changeTextDlg();
-    } else if (getButton() == WorkToolBar::tbb_Object_Node) {
-         dynamic_cast<ObjectNodeWidget*>(umlWidget)->askForObjectNodeType(umlWidget);
-    } else if (getButton() == WorkToolBar::tbb_PrePostCondition) {
-         dynamic_cast<NoteWidget*>(umlWidget)->askForNoteType(umlWidget);
+    switch (getButton()) {
+    case WorkToolBar::tbb_Activity:
+        {
+            Dialog_Utils::askNameForWidget(
+                umlWidget, i18n("Enter Activity Name"),
+                i18n("Enter the name of the new activity:"), i18n("new activity"));
+        }
+        break;
+    case WorkToolBar::tbb_Accept_Signal:
+    case WorkToolBar::tbb_Send_Signal:
+        {
+            Dialog_Utils::askNameForWidget(
+                umlWidget, i18n("Enter Signal Name"),
+                i18n("Enter Signal"), i18n("new Signal"));
+        }
+        break;
+    case WorkToolBar::tbb_Accept_Time_Event:
+        {
+            Dialog_Utils::askNameForWidget(
+                umlWidget, i18n("Enter Time Event Name"),
+                i18n("Enter Time Event"), i18n("new time event"));
+        }
+        break;
+    case WorkToolBar::tbb_Seq_Combined_Fragment:
+        {
+            dynamic_cast<CombinedFragmentWidget*>(umlWidget)->askNameForWidgetType(
+                umlWidget, i18n("Enter Combined Fragment Name"),
+                i18n("Enter the Combined Fragment"), i18n("new Combined Fragment"));
+        }
+        break;
+    case WorkToolBar::tbb_State:
+        {
+            Dialog_Utils::askNameForWidget(
+                umlWidget, i18n("Enter State Name"),
+                i18n("Enter the name of the new state:"), i18n("new state"));
+        }
+        break;
+    case WorkToolBar::tbb_Text:
+        {
+            // It is pretty invisible otherwise.
+            FloatingTextWidget* ft = (FloatingTextWidget*) umlWidget;
+            ft->showChangeTextDialog();
+        }
+        break;
+    case WorkToolBar::tbb_Object_Node:
+        {
+            dynamic_cast<ObjectNodeWidget*>(umlWidget)->askForObjectNodeType(umlWidget);
+        }
+        break;
+    case WorkToolBar::tbb_PrePostCondition:
+        {
+            dynamic_cast<NoteWidget*>(umlWidget)->askForNoteType(umlWidget);
+        }
+        break;
+    default:
+        uWarning() << "Unknown ToolBar_Buttons: " << QLatin1String(ENUM_NAME(WorkToolBar, WorkToolBar::ToolBar_Buttons, getButton()));
+        break;
     }
 
     // Create the widget. Some setup functions can remove the widget.
-    if (umlWidget != NULL) {
+    if (umlWidget != 0) {
         m_pUMLView->setupNewWidget(umlWidget);
     }
 
