@@ -1,11 +1,10 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2006                                               *
+ *   copyright (C) 2002-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -99,12 +98,12 @@ public:
     /**
      * Overrides the equality test operator.
      */
-    bool operator==(const AssociationWidget & Other);
+    bool operator==(const AssociationWidget & Other) const;
 
     /**
      * Overrides the != operator.
      */
-    bool operator!=(AssociationWidget & Other);
+    bool operator!=(AssociationWidget & Other) const;
 
     /**
      * Activates the AssociationWidget after a load.
